@@ -28,12 +28,6 @@ wkb_has_missing <- function(wkb) {
   cpp_wkb_has_missing(wkb)
 }
 
-#' @rdname wkt_has_missing
-#' @export
-wksxp_has_missing <- function(wksxp) {
-  cpp_wksxp_has_missing(wksxp)
-}
-
 #' @rdname wkt_has_missing
 #' @export
 wkt_is_finite <- function(wkt) {
@@ -45,9 +39,3 @@ wkt_is_finite <- function(wkt) {
 wkb_is_finite <- function(wkb) {
   !cpp_wkb_has_non_finite(wkb)
 }
-
-#' @rdname wkt_has_missing
-#' @export
-wksxp_is_finite <- function(wksxp) {
-  !cpp_wksxp_has_non_finite(wksxp)
-}
